<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru_RU">
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="99"/>
        <source>Current device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="170"/>
        <source>Identify failed, Please retry.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="51"/>
        <source>Please select the biometric device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="56"/>
        <source>Device type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="73"/>
        <source>Device name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="83"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="37"/>
        <source>FingerPrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="39"/>
        <source>FingerVein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="41"/>
        <source>Iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="43"/>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="45"/>
        <source>VoicePrint</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FakeDialog</name>
    <message>
        <location filename="../common/fakedialog.cpp" line="63"/>
        <source>cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GreeterWindow</name>
    <message>
        <location filename="../greeter/greeterwindow.cpp" line="648"/>
        <location filename="../greeter/greeterwindow.cpp" line="1007"/>
        <source>Login</source>
        <translation type="unfinished">вход</translation>
    </message>
</context>
<context>
    <name>GreeterWrapper</name>
    <message>
        <location filename="../greeter/greeterwrapper.cpp" line="116"/>
        <source>failed to start session.</source>
        <translation>не начала сессии.</translation>
    </message>
</context>
<context>
    <name>IconEdit</name>
    <message>
        <location filename="../greeter/iconedit.cpp" line="178"/>
        <location filename="../greeter/iconedit.cpp" line="218"/>
        <source>Password: </source>
        <translation type="unfinished">пароль: </translation>
    </message>
    <message>
        <location filename="../greeter/iconedit.cpp" line="180"/>
        <location filename="../greeter/iconedit.cpp" line="220"/>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeyboardWidget</name>
    <message>
        <location filename="../VirtualKeyboard/src/keyboardwidget.ui" line="29"/>
        <source>KeyboardWidget</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LoginWindow</name>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="219"/>
        <location filename="../greeter/loginwindow.cpp" line="308"/>
        <location filename="../greeter/loginwindow.cpp" line="665"/>
        <source>Login</source>
        <translation>вход</translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="353"/>
        <source>logged in</source>
        <translation>войти в систему</translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="442"/>
        <source>login</source>
        <translation>вход</translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="558"/>
        <location filename="../greeter/loginwindow.cpp" line="706"/>
        <source>Please enter your password or enroll your fingerprint </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="560"/>
        <source>Password: </source>
        <translation>пароль: </translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="563"/>
        <source>Username</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="1017"/>
        <source>Too many unsuccessful attempts,please enter password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="631"/>
        <location filename="../greeter/loginwindow.cpp" line="635"/>
        <location filename="../greeter/loginwindow.cpp" line="1020"/>
        <source>Authentication failure, Please try again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="215"/>
        <location filename="../greeter/loginwindow.cpp" line="670"/>
        <location filename="../greeter/loginwindow.cpp" line="926"/>
        <source>Retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="206"/>
        <location filename="../greeter/loginwindow.cpp" line="891"/>
        <source>Biometric Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="209"/>
        <location filename="../greeter/loginwindow.cpp" line="904"/>
        <source>Password Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/loginwindow.cpp" line="212"/>
        <location filename="../greeter/loginwindow.cpp" line="916"/>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Incorrect password, please input again</source>
        <translation type="obsolete">неверный пароль, пожалуйста, введите снова</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../display-switch/ui_mainwindow.h" line="127"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <location filename="../greeter/powerwindow.cpp" line="151"/>
        <location filename="../greeter/powerwindow.cpp" line="166"/>
        <source>Switch User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/powerwindow.cpp" line="206"/>
        <source>Suspend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/powerwindow.cpp" line="221"/>
        <source>Sleep</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/powerwindow.cpp" line="152"/>
        <location filename="../greeter/powerwindow.cpp" line="179"/>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/powerwindow.cpp" line="153"/>
        <location filename="../greeter/powerwindow.cpp" line="192"/>
        <source>Power Off</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>UsersModel</name>
    <message>
        <location filename="../greeter/usersmodel.cpp" line="48"/>
        <location filename="../greeter/usersmodel.cpp" line="50"/>
        <source>Guest</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../greeter/usersmodel.cpp" line="58"/>
        <source>Guest Session</source>
        <translation>гость.</translation>
    </message>
    <message>
        <location filename="../greeter/usersmodel.cpp" line="76"/>
        <location filename="../greeter/usersmodel.cpp" line="78"/>
        <location filename="../greeter/usersmodel.cpp" line="85"/>
        <source>Login</source>
        <translation>вход</translation>
    </message>
</context>
</TS>
